@@ -1,4 +1,5 @@
-use futures::StreamExt;
+use futures_util::StreamExt;
+use opentelemetry::global;
 use opentelemetry::global::shutdown_tracer_provider;
 use opentelemetry::trace::{Span, SpanKind, Tracer};
 use opentelemetry_otlp::WithExportConfig;
@@ -9,6 +10,8 @@ use opentelemetry_proto::tonic::collector::trace::v1::{
 use std::{net::SocketAddr, sync::Mutex};
 use tokio::sync::mpsc;
 use tokio_stream::wrappers::TcpListenerStream;
+#[cfg(feature = "gzip-tonic")]
+use tonic::codec::CompressionEncoding;
 
 struct MockServer {
     tx: Mutex<mpsc::Sender<ExportTraceServiceRequest>>,
@@ -57,6 +60,10 @@ async fn setup() -> (SocketAddr, mpsc::Receiver<ExportTraceServiceRequest>) {
     });
 
     let (req_tx, req_rx) = mpsc::channel(10);
+    #[cfg(feature = "gzip-tonic")]
+    let service = TraceServiceServer::new(MockServer::new(req_tx))
+        .accept_compressed(CompressionEncoding::Gzip);
+    #[cfg(not(feature = "gzip-tonic"))]
     let service = TraceServiceServer::new(MockServer::new(req_tx));
     tokio::task::spawn(async move {
         tonic::transport::Server::builder()
@@ -74,20 +81,31 @@ async fn smoke_tracer() {
     let (addr, mut req_rx) = setup().await;
 
     {
-        println!("Installing tracer...");
+        println!("Installing tracer provider...");
         let mut metadata = tonic::metadata::MetadataMap::new();
         metadata.insert("x-header-key", "header-value".parse().unwrap());
-        let tracer = opentelemetry_otlp::new_pipeline()
+        let tracer_provider = opentelemetry_otlp::new_pipeline()
             .tracing()
             .with_exporter(
+                #[cfg(feature = "gzip-tonic")]
+                opentelemetry_otlp::new_exporter()
+                    .tonic()
+                    .with_compression(opentelemetry_otlp::Compression::Gzip)
+                    .with_endpoint(format!("http://{}", addr))
+                    .with_metadata(metadata),
+                #[cfg(not(feature = "gzip-tonic"))]
                 opentelemetry_otlp::new_exporter()
                     .tonic()
                     .with_endpoint(format!("http://{}", addr))
                     .with_metadata(metadata),
             )
-            .install_batch(opentelemetry::runtime::Tokio)
+            .install_batch(opentelemetry_sdk::runtime::Tokio)
             .expect("failed to install");
 
+        global::set_tracer_provider(tracer_provider);
+
+        let tracer = global::tracer("smoke");
+
         println!("Sending span...");
         let mut span = tracer
             .span_builder("my-test-span")
@@ -103,15 +121,15 @@ async fn smoke_tracer() {
     let req = req_rx.recv().await.expect("missing export request");
     let first_span = req
         .resource_spans
-        .get(0)
+        .first()
         .unwrap()
         .scope_spans
-        .get(0)
+        .first()
         .unwrap()
         .spans
-        .get(0)
+        .first()
         .unwrap();
     assert_eq!("my-test-span", first_span.name);
-    let first_event = first_span.events.get(0).unwrap();
+    let first_event = first_span.events.first().unwrap();
     assert_eq!("my-test-event", first_event.name);
 }
